@@ -1,7 +1,7 @@
 package Perinci::Sub::ConvertArgs::Array;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2015-12-29'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -57,6 +57,7 @@ sub convert_args_to_array {
     my @array;
 
     while (my ($k, $v) = each %$args) {
+        next if $k =~ /\A-/; # skip special arguments
         my $as = $args_prop->{$k};
         return [412, "Argument $k: Not specified in args property"] unless $as;
         my $pos = $as->{pos};
@@ -91,7 +92,7 @@ Perinci::Sub::ConvertArgs::Array - Convert hash arguments to array
 
 =head1 VERSION
 
-This document describes version 0.07 of Perinci::Sub::ConvertArgs::Array (from Perl distribution Perinci-Sub-ConvertArgs-Array), released on 2015-09-03.
+This document describes version 0.08 of Perinci::Sub::ConvertArgs::Array (from Perl distribution Perinci-Sub-ConvertArgs-Array), released on 2015-12-29.
 
 =head1 SYNOPSIS
 
@@ -130,6 +131,8 @@ then 'convert_args_to_array(args=>{a=>2, b=>3}, meta=>$meta)' will produce:
 
  [200, "OK", [2, 3]]
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -157,7 +160,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-ConvertArgs-Array>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-ConvertArgs-Array>.
 
 =head1 BUGS
 
